OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "Não foi possível eliminar %s de forma permanente",
    "Couldn't restore %s" : "Não foi possível restaurar %s",
    "Deleted files" : "Ficheiros eliminados",
    "Restore" : "Restaurar",
    "Delete" : "Eliminar",
    "Delete permanently" : "Eliminar permanentemente",
    "Error" : "Erro",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "restored" : "Restaurado",
    "No deleted files" : "Sem ficheiros eliminados",
    "You will be able to recover deleted files from here" : "Poderá recuperar ficheiros eliminados a partir daqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Selecionar todos",
    "Name" : "Nome",
    "Deleted" : "Eliminado"
},
"nplurals=2; plural=(n != 1);");
